@@ -52,20 +52,20 @@ sim_df(mtcars, 50, between = "am") %>%
 
 ## -----------------------------------------------------------------------------
 data <- sim_design(2, 2, n = 10, plot = FALSE)
-data$A1[1:3] <- NA
-data$A2[1:6] <- NA
+data$W1a[1:3] <- NA
+data$W1b[1:6] <- NA
 data
 
 ## -----------------------------------------------------------------------------
-simdat <- sim_df(data, between = "B", n = 1000, 
+simdat <- sim_df(data, between = "B1", n = 1000, 
                  missing = TRUE)
 
 ## ---- echo = FALSE, results = 'asis'------------------------------------------
 simdat %>%
-  mutate(A1 = ifelse(is.na(A1), "NA", "not NA"),
-         A2 = ifelse(is.na(A2), "NA", "not NA")) %>%
-  count(B, A1, A2) %>%
-  group_by(B) %>%
+  mutate(W1a = ifelse(is.na(W1a), "NA", "not NA"),
+         W1b = ifelse(is.na(W1b), "NA", "not NA")) %>%
+  count(B1, W1a, W1b) %>%
+  group_by(B1) %>%
   mutate(n = round(n/sum(n), 2)) %>%
   knitr::kable()
 
